#!/bin/sh

# Get the current directory where the install.sh script is located
INSTALL_DIR="$(cd "$(dirname "$0")"; pwd)"

# Define the Python binary path
PYTHON_BIN="$INSTALL_DIR/python3_ntoarmv7-qnx-static/tools/python3/python3"
PYTHON_HOME="$INSTALL_DIR/python3_ntoarmv7-qnx-static"

# Export PYTHONHOME
export PYTHONHOME="$PYTHON_HOME"

# Add PYTHONHOME to .profile if it doesn't already exist
if ! grep -q "PYTHONHOME" "$HOME/.profile"; then
    echo "export PYTHONHOME=\"$PYTHON_HOME\"" >> "$HOME/.profile"
    echo "PYTHONHOME added to .profile"
else
    echo "PYTHONHOME is already set in .profile"
fi

# Create $HOME/usr/local/bin directory if it doesn't exist
TARGET_BIN_DIR="$HOME/usr/local/bin"
if [ ! -d "$TARGET_BIN_DIR" ]; then
    mkdir -p "$TARGET_BIN_DIR"
    echo "Created $TARGET_BIN_DIR directory"
fi

# **Make the python3 binary executable**
if [ -f "$PYTHON_BIN" ]; then
    chmod +x "$PYTHON_BIN"
    echo "Made $PYTHON_BIN executable"
else
    echo "Python binary not found: $PYTHON_BIN"
    exit 1
fi

# Create a symlink for python3 in $HOME/usr/local/bin
if [ -x "$PYTHON_BIN" ]; then
    ln -sf "$PYTHON_BIN" "$TARGET_BIN_DIR/python3"
    echo "Symlink for python3 created in $TARGET_BIN_DIR"
else
    echo "Python binary not executable: $PYTHON_BIN"
    exit 1
fi

# Add $HOME/usr/local/bin to PATH in .profile if it's not already there
if ! grep -q 'export PATH="$HOME/usr/local/bin:$PATH"' "$HOME/.profile"; then
    echo 'export PATH="$HOME/usr/local/bin:$PATH"' >> "$HOME/.profile"
    echo "Added $HOME/usr/local/bin to PATH in .profile"
else
    echo "$HOME/usr/local/bin is already in PATH in .profile"
fi

# Inform the user to source .profile
echo "Installation complete. Please run 'source ~/.profile' or log out and log back in to update your environment variables."

# Verify installation (this may not work until .profile is reloaded)
echo "Running '$HOME/usr/local/bin/python3 --version' to verify installation:"
"$HOME/usr/local/bin/python3" --version
